# Imports from django
from django.forms import widgets
from django.utils.safestring import mark_safe


class StaggeredSelectWidget(widgets.TextInput):
    '''
    '''
    class Media:
        css = {
            'all': ('staggered_select/css/staggered.css',),
        }
        js = (
            'staggered_select/js/staggered.js',
        )

    def render(self, name, value, attrs=None):
        html = super(StaggeredSelectWidget, self).render(
            name,
            value,
            attrs
        )

        html = [
            '<div class="sselect-message">Choose a <span class="watched-verbose">value</span> to see options.</div>',
            '<select class="staggered-select">',
            '</select>',
            '%s' % html,
        ]

        return mark_safe(''.join(html))



# Imports from django
from django.db import models
from django import forms


# Imports from staggered-select
from staggered_selects.widgets import StaggeredSelectWidget


class StaggeredSelectFormField(forms.CharField):
    widget = StaggeredSelectWidget


class StaggeredSelectField(models.CharField):
    def __init__(self, *args, **kwargs):
        self.watched_field = kwargs.pop('watched_field', '')
        self.get_choices = kwargs.pop('get_choices_function', '')

        super(StaggeredSelectField, self).__init__(
            *args,
            **kwargs
        )

    def formfield(self, **kwargs):
        defaults = {}
        defaults.update(kwargs)

        defaults['widget'] = StaggeredSelectWidget
        defaults['form_class'] = StaggeredSelectFormField

        form_field = super(StaggeredSelectField, self).formfield(**defaults)

        form_field.widget.attrs['watched_field'] = self.watched_field
        form_field.widget.attrs['get_choices_function'] = self.get_choices

        return form_field




#!/usr/bin/python
from setuptools import setup, find_packages


from staggered_selects import __version__, __version_info__


github_url = 'https://github.com/datahub/django-staggered-selects'
github_tag_version = __version__


setup(
    name='django-staggered-selects',
    version=__version__,
    description='Staggered drop-down menus for the Django admin',
    url=github_url,
    download_url='%s/tarball/%s' % (github_url, __version__),
    author='Allan James Vestal',
    author_email='datahub@jrn.com',
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    license='MIT License',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)
